
import { Configuration, App, Inject } from '@midwayjs/decorator';
import * as koa from '@midwayjs/koa';
import * as validate from '@midwayjs/validate';
import * as info from '@midwayjs/info';
import * as staticFile from '@midwayjs/static-file';
import { join, resolve } from 'path';
import { ReportMiddleware } from './middleware/report.middleware';
import { createServer as createViteServer } from 'vite'
import { Context } from 'koa';
import { ENV_TYPE } from './const';
import { initViteSSR } from '@wcrane/ssr'

const koaConnect = require('koa-connect')
@Configuration({
  imports: [
    koa,
    validate,
    {
      component: info,
      enabledEnvironment: ['local'],
    },
    staticFile
  ],
  importConfigs: [join(__dirname, './config')],
})
export class ContainerLifeCycle {
  @App()
  app: koa.Application;
  @Inject()
  ctx: Context
  async onReady() {
    // add middleware

    const env = this.app.getEnv()

    // console.log(process.env.NODE_ENV)
    this.app.useMiddleware([ReportMiddleware]);
    initViteSSR(this.app)
    if (env === ENV_TYPE.DEV) {
      const viteServer = await createViteServer({
        root: resolve(process.cwd(), "web"),
        server: { middlewareMode: true }
      })
      this.app.use(koaConnect(viteServer.middlewares))
      this.app.setAttr('vite', viteServer)
    }

  }
}
